@@ -80,8 +80,9 @@ namespace muFFT {
     if (not this->has_plan_for(nb_dof_per_pixel)) {
       std::stringstream message{};
       message << "No plan has been created for " << nb_dof_per_pixel
-              << " degrees of freedom per pixel. Use "
-                 "`muFFT::FFTEngineBase::create_plan` to prepare a plan.";
+              << " degrees of freedom per pixel on MPI rank "
+              << this->comm.rank() << ". Use muFFT::FFTEngineBase::create_plan`"
+              << " to prepare a plan.";
       throw FFTEngineError{message.str()};
     }
 
@@ -191,8 +192,9 @@ namespace muFFT {
     if (not this->has_plan_for(nb_dof_per_pixel)) {
       std::stringstream message{};
       message << "No plan has been created for " << nb_dof_per_pixel
-              << " degrees of freedom per pixel. Use "
-                 "`muFFT::FFTEngineBase::create_plan` to prepare a plan.";
+              << " degrees of freedom per pixel on MPI rank "
+              << this->comm.rank() << ". Use muFFT::FFTEngineBase::create_plan`"
+              << " to prepare a plan.";
       throw FFTEngineError{message.str()};
     }
 
@@ -302,8 +304,9 @@ namespace muFFT {
     if (not this->has_plan_for(nb_dof_per_pixel)) {
       std::stringstream message{};
       message << "No plan has been created for " << nb_dof_per_pixel
-              << " degrees of freedom per pixel. Use "
-                 "`muFFT::FFTEngineBase::create_plan` to prepare a plan.";
+              << " degrees of freedom per pixel on MPI rank "
+              << this->comm.rank() << ". Use muFFT::FFTEngineBase::create_plan`"
+              << " to prepare a plan.";
       throw FFTEngineError{message.str()};
     }
 
@@ -413,8 +416,9 @@ namespace muFFT {
     if (not this->has_plan_for(nb_dof_per_pixel)) {
       std::stringstream message{};
       message << "No plan has been created for " << nb_dof_per_pixel
-              << " degrees of freedom per pixel. Use "
-                 "`muFFT::FFTEngineBase::create_plan` to prepare a plan.";
+              << " degrees of freedom per pixel on MPI rank "
+              << this->comm.rank() << ". Use muFFT::FFTEngineBase::create_plan`"
+              << " to prepare a plan.";
       throw FFTEngineError{message.str()};
     }
 
@@ -521,7 +525,7 @@ namespace muFFT {
   auto
   FFTEngineBase::register_fourier_space_field(const std::string & unique_name,
                                               const Index_t & nb_dof_per_pixel)
-      -> FourierField_t & {
+      -> muGrid::ComplexField & {
     this->create_plan(nb_dof_per_pixel);
     return this->fourier_field_collection.register_complex_field(
         unique_name, nb_dof_per_pixel, PixelTag);
@@ -531,7 +535,7 @@ namespace muFFT {
   auto
   FFTEngineBase::register_fourier_space_field(const std::string & unique_name,
                                               const Shape_t & shape)
-  -> FourierField_t & {
+      -> muGrid::ComplexField & {
     this->create_plan(shape);
     return this->fourier_field_collection.register_complex_field(
         unique_name, shape, PixelTag);
@@ -723,7 +727,14 @@ namespace muFFT {
   }
 
   /* ---------------------------------------------------------------------- */
-  const typename FFTEngineBase::Pixels_t & FFTEngineBase::get_pixels() const {
+  const typename FFTEngineBase::Pixels_t &
+  FFTEngineBase::get_real_pixels() const {
+    return this->real_field_collection.get_pixels();
+  }
+
+  /* ---------------------------------------------------------------------- */
+  const typename FFTEngineBase::Pixels_t &
+  FFTEngineBase::get_fourier_pixels() const {
     return this->fourier_field_collection.get_pixels();
   }
 
