@@ -53,7 +53,8 @@ namespace muGrid {
         nb_cols{this->field.get_default_nb_cols(iter_type)} {
     if (field.get_storage_order() != StorageOrder::ColMajor) {
       std::stringstream s;
-      s << "FieldMap requires column-major storage order, but storage order is "
+      s << "FieldMap requires column-major storage order, but storage order of "
+        << "field '" << field.get_name() << "' is "
         << field.get_storage_order();
       throw RuntimeError(s.str());
     }
@@ -76,7 +77,8 @@ namespace muGrid {
         nb_rows{nb_rows_}, nb_cols{this->stride / nb_rows_} {
     if (field.get_storage_order() != StorageOrder::ColMajor) {
       std::stringstream s;
-      s << "FieldMap requires column-major storage order, but storage order is "
+      s << "FieldMap requires column-major storage order, but storage order of "
+        << "field '" << field.get_name() << "' is "
         << field.get_storage_order();
       throw RuntimeError(s.str());
     }
@@ -106,7 +108,8 @@ namespace muGrid {
         data_ptr{other.data_ptr}, is_initialised{other.is_initialised} {
     if (field.get_storage_order() != StorageOrder::ColMajor) {
       std::stringstream s;
-      s << "FieldMap requires column-major storage order, but storage order is "
+      s << "FieldMap requires column-major storage order, but storage order of "
+        << "field '" << field.get_name() << "' is "
         << field.get_storage_order();
       throw RuntimeError(s.str());
     }
@@ -210,6 +213,16 @@ namespace muGrid {
                        *this);
   }
 
+  /* ---------------------------------------------------------------------- */
+  template <typename T, Mapping Mutability>
+  auto FieldMap<T, Mutability>::sum() const -> PlainType {
+    PlainType sum{PlainType::Zero(this->nb_rows, this->nb_cols)};
+    for (auto && val : *this) {
+      sum += val;
+    }
+    return sum;
+  }
+
   /* ---------------------------------------------------------------------- */
   template <typename T, Mapping Mutability>
   auto FieldMap<T, Mutability>::mean() const -> PlainType {
@@ -221,6 +234,12 @@ namespace muGrid {
     return mean;
   }
 
+  /* ---------------------------------------------------------------------- */
+  template <typename T, Mapping Mutability>
+  auto FieldMap<T, Mutability>::get_field() const -> const Field_t & {
+    return this->field;
+  }
+
   /* ---------------------------------------------------------------------- */
   template class FieldMap<Real, Mapping::Const>;
   template class FieldMap<Real, Mapping::Mut>;
